# Apunim: Attributing polarization to sociodemographic groups

Repository housing the implementation of the Aposteriori Unimodality measure, available as a PyPi module. 

Includes two functions: `dfu`, which calculates the Distance From Unimodality (and also implements the normalized variant - nDFU), and `aposteriori-unimodality`, which calculates the Aposteriori Unimodality statistic for each sociodemographic group.

## Installation

### PyPi (recommended)
```bash
pip install apunim
```

### Local installation
```bash
git clone https://github.com/dimits-ts/apunim.git
cd apunim
pip install .
```

## Usage

Documentation TODO